# Projects

The projects are those packages that add functionality to the CGSE framework.

The projects live under the folder `projects`, and they are organised in _generic_ and _specific_ projects. Generic 
projects do not have an implementation that is specific for one particular project, while, obviously, specific 
projects have. We currently have the following generic packages:

- `cgse-tools`
- `symetrie-hexapod`
- `keithley-tempcontrol`

and then there are the project specific packages:

- `plato-fits`
- `plato-hdf5`
- `plato-spw`
